<?php
/**
 * Dog Pet House functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package dog_pet_house
 */

$dog_pet_house_theme_data = wp_get_theme();
if( ! defined( 'DOG_PET_HOUSE_THEME_VERSION' ) ) define ( 'DOG_PET_HOUSE_THEME_VERSION', $dog_pet_house_theme_data->get( 'Version' ) );
if( ! defined( 'DOG_PET_HOUSE_THEME_NAME' ) ) define( 'DOG_PET_HOUSE_THEME_NAME', $dog_pet_house_theme_data->get( 'Name' ) );
if( ! defined( 'DOG_PET_HOUSE_THEME_TEXTDOMAIN' ) ) define( 'DOG_PET_HOUSE_THEME_TEXTDOMAIN', $dog_pet_house_theme_data->get( 'TextDomain' ) );

if ( ! defined( 'DOG_PET_HOUSE_VERSION' ) ) {
	define( 'DOG_PET_HOUSE_VERSION', '1.0.0' );
}

if ( ! function_exists( 'dog_pet_house_setup' ) ) :
	
	function dog_pet_house_setup() {
		
		load_theme_textdomain( 'dog-pet-house', get_template_directory() . '/languages' );

		add_theme_support( 'woocommerce' );

		add_theme_support( 'automatic-feed-links' );
		
		add_theme_support( 'title-tag' );

		add_theme_support( 'post-thumbnails' );

		register_nav_menus(
			array(
				'primary' => esc_html__( 'Primary', 'dog-pet-house' ),
			)
		);

		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
				'woocommerce',
			)
		);

		add_theme_support(
			'custom-background',
			apply_filters(
				'dog_pet_house_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		add_theme_support( 'post-formats', array(
			'image',
			'video',
			'gallery',
			'audio', 
		) );

		add_theme_support( 'customize-selective-refresh-widgets' );

		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);

		add_theme_support( 'align-wide' );

		add_theme_support( 'responsive-embeds' );
	}
endif;
add_action( 'after_setup_theme', 'dog_pet_house_setup' );

function dog_pet_house_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'dog_pet_house_content_width', 640 );
}
add_action( 'after_setup_theme', 'dog_pet_house_content_width', 0 );

function dog_pet_house_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'dog-pet-house' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'dog-pet-house' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title"><span>',
			'after_title'   => '</span></h2>',
		)
	);

	// Regsiter 4 footer widgets.
	// Regsiter 4 footer widgets.
	$dog_pet_house_footer_widget_column = get_theme_mod('dog_pet_house_footer_widget_column','4');
	for ($i=1; $i<=$dog_pet_house_footer_widget_column; $i++) {
		register_sidebar( array(
			'name' => __( 'Footer  ', 'dog-pet-house' )  . $i,
			'id' => 'dog-pet-house-footer-widget-' . $i,
			'description' => __( 'The Footer Widget Area', 'dog-pet-house' )  . $i,
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '</aside>',
			'before_title' => '<div class="widget-header"><h4 class="widget-title">',
			'after_title' => '</h4></div>',
		) );
	}
}
add_action( 'widgets_init', 'dog_pet_house_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function dog_pet_house_scripts() {
	// Append .min if SCRIPT_DEBUG is false.
	$min = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

	// Slick style.
	wp_enqueue_style( 'dog-pet-house-slick-style', get_template_directory_uri() . '/resource/css/slick' . $min . '.css', array(), '1.8.1' );

	// Fontawesome style.
	wp_enqueue_style( 'dog-pet-house-fontawesome-style', get_template_directory_uri() . '/resource/css/fontawesome' . $min . '.css', array(), '5.15.4' );

	// Main style.
	wp_enqueue_style( 'dog-pet-house-style', get_template_directory_uri() . '/style.css', array(), DOG_PET_HOUSE_VERSION );
	
	// RTL style.
	wp_style_add_data('dog-pet-house-style', 'rtl', 'replace');

	// Navigation script.
	wp_enqueue_script( 'dog-pet-house-navigation-script', get_template_directory_uri() . '/resource/js/navigation' . $min . '.js', array(), DOG_PET_HOUSE_VERSION, true );

	// Slick script.
	wp_enqueue_script( 'dog-pet-house-slick-script', get_template_directory_uri() . '/resource/js/slick' . $min . '.js', array( 'jquery' ), '1.8.1', true );

	// Custom script
	wp_enqueue_script( 'water-sports-gear-custom-script', get_template_directory_uri() . '/resource/js/custom.js', array( 'jquery' ), DOG_PET_HOUSE_VERSION, true );

	// Localize the sticky header setting
	$dog_pet_house_enable_sticky_header = get_theme_mod('dog_pet_house_enable_sticky_header', false);
	wp_localize_script( 'water-sports-gear-custom-script', 'stickyHeaderSettings', array(
		'isEnabled' => $dog_pet_house_enable_sticky_header,
	));

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	// Include the file.
	require_once get_theme_file_path( 'theme-library/function-files/wptt-webfont-loader.php' );

	// Load the webfont.
	wp_enqueue_style(
		'lilita-one',
		wptt_get_webfont_url( 'https://fonts.googleapis.com/css2?family=Lilita+One&display=swap' ),
		array(),
		'1.0'
	);

	wp_enqueue_style(
		'kodchasan',
		wptt_get_webfont_url( 'https://fonts.googleapis.com/css2?family=Kodchasan:ital,wght@0,200;0,300;0,400;0,500;0,600;0,700;1,200;1,300;1,400;1,500;1,600;1,700&display=swap' ),
		array(),
		'1.0'
	);

}
add_action( 'wp_enqueue_scripts', 'dog_pet_house_scripts' );

/**
 * Include wptt webfont loader.
 */
require_once get_theme_file_path( 'theme-library/function-files/wptt-webfont-loader.php' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/theme-library/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/theme-library/function-files/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/theme-library/function-files/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/theme-library/customizer.php';

/**
 * Breadcrumb
 */
require get_template_directory() . '/theme-library/function-files/class-breadcrumb-trail.php';

/**
 * Getting Started
*/
require get_template_directory() . '/theme-library/getting-started/getting-started.php';

/**
 * Google Fonts
 */
require get_template_directory() . '/theme-library/function-files/google-fonts.php';

/**
 * Dynamic CSS
 */
require get_template_directory() . '/theme-library/dynamic-css.php';

/* TGM. */
// require get_parent_theme_file_path( '/inc/tgm.php' );
require get_parent_theme_file_path( '/theme-wizard/config.php' );


// Enqueue Customizer live preview script
function dog_pet_house_customizer_live_preview() {
    wp_enqueue_script(
        'dog-pet-house-customizer',
        get_template_directory_uri() . '/js/customizer.js',
        array('jquery', 'customize-preview'),
        '',
        true
    );
}
add_action('customize_preview_init', 'dog_pet_house_customizer_live_preview');


function dog_pet_house_customize_css() {
    ?>
    <style type="text/css">
        :root {
            --primary-color: <?php echo esc_html( get_theme_mod( 'primary_color', '#6839cc' ) ); ?>;
        }
    </style>
    <?php
}
add_action( 'wp_head', 'dog_pet_house_customize_css' );

function dog_pet_house_enqueue_selected_fonts() {
    $dog_pet_house_fonts_url = dog_pet_house_get_fonts_url();
    if (!empty($dog_pet_house_fonts_url)) {
        wp_enqueue_style('dog-pet-house-google-fonts', $dog_pet_house_fonts_url, array(), null);
    }
}
add_action('wp_enqueue_scripts', 'dog_pet_house_enqueue_selected_fonts');

function dog_pet_house_layout_customizer_css() {
    $dog_pet_house_margin = get_theme_mod('dog_pet_house_layout_width_margin', 50);
    ?>
    <style type="text/css">
        body.site-boxed--layout #page  {
            margin: 0 <?php echo esc_attr($dog_pet_house_margin); ?>px;
        }
    </style>
    <?php
}
add_action('wp_head', 'dog_pet_house_layout_customizer_css');

function dog_pet_house_blog_layout_customizer_css() {
    // Retrieve the blog layout option
    $dog_pet_house_blog_layout_option = get_theme_mod('dog_pet_house_blog_layout_option_setting', 'Left');

    // Initialize custom CSS variable
    $dog_pet_house_custom_css = '';

    // Generate custom CSS based on the layout option
    if ($dog_pet_house_blog_layout_option === 'Default') {
        $dog_pet_house_custom_css .= '.mag-post-detail { text-align: center; }';
    } elseif ($dog_pet_house_blog_layout_option === 'Left') {
        $dog_pet_house_custom_css .= '.mag-post-detail { text-align: left; }';
    } elseif ($dog_pet_house_blog_layout_option === 'Right') {
        $dog_pet_house_custom_css .= '.mag-post-detail { text-align: right; }';
    }

    // Output the combined CSS
    ?>
    <style type="text/css">
        <?php echo wp_kses($dog_pet_house_custom_css, array( 'style' => array(), 'text-align' => array() )); ?>
    </style>
    <?php
}
add_action('wp_head', 'dog_pet_house_blog_layout_customizer_css');

function dog_pet_house_sidebar_width_customizer_css() {
    $dog_pet_house_sidebar_width = get_theme_mod('dog_pet_house_sidebar_width', '30');
    ?>
    <style type="text/css">
        .right-sidebar .asterthemes-wrapper .asterthemes-page {
            grid-template-columns: auto <?php echo esc_attr($dog_pet_house_sidebar_width); ?>%;
        }
        .left-sidebar .asterthemes-wrapper .asterthemes-page {
            grid-template-columns: <?php echo esc_attr($dog_pet_house_sidebar_width); ?>% auto;
        }
    </style>
    <?php
}
add_action('wp_head', 'dog_pet_house_sidebar_width_customizer_css');

if ( ! function_exists( 'dog_pet_house_get_page_title' ) ) {
    function dog_pet_house_get_page_title() {
        $dog_pet_house_title = '';

        if (is_404()) {
            $dog_pet_house_title = esc_html__('Page Not Found', 'dog-pet-house');
        } elseif (is_search()) {
            $dog_pet_house_title = esc_html__('Search Results for: ', 'dog-pet-house') . esc_html(get_search_query());
        } elseif (is_home() && !is_front_page()) {
            $dog_pet_house_title = esc_html__('Blogs', 'dog-pet-house');
        } elseif (function_exists('is_shop') && is_shop()) {
            $dog_pet_house_title = esc_html__('Shop', 'dog-pet-house');
        } elseif (is_page()) {
            $dog_pet_house_title = get_the_title();
        } elseif (is_single()) {
            $dog_pet_house_title = get_the_title();
        } elseif (is_archive()) {
            $dog_pet_house_title = get_the_archive_title();
        } else {
            $dog_pet_house_title = get_the_archive_title();
        }

        return apply_filters('dog_pet_house_page_title', $dog_pet_house_title);
    }
}

if ( ! function_exists( 'dog_pet_house_has_page_header' ) ) {
    function dog_pet_house_has_page_header() {
        // Default to true (display header)
        $dog_pet_house_return = true;

        // Custom conditions for disabling the header
        if ('hide-all-devices' === get_theme_mod('dog_pet_house_page_header_visibility', 'all-devices')) {
            $dog_pet_house_return = false;
        }

        // Apply filters and return
        return apply_filters('dog_pet_house_display_page_header', $dog_pet_house_return);
    }
}

if ( ! function_exists( 'dog_pet_house_page_header_style' ) ) {
    function dog_pet_house_page_header_style() {
        $dog_pet_house_style = get_theme_mod('dog_pet_house_page_header_style', 'default');
        return apply_filters('dog_pet_house_page_header_style', $dog_pet_house_style);
    }
}

function dog_pet_house_page_title_customizer_css() {
    $dog_pet_house_layout_option = get_theme_mod('dog_pet_house_page_header_layout', 'left');
    ?>
    <style type="text/css">
        .asterthemes-wrapper.page-header-inner {
            <?php if ($dog_pet_house_layout_option === 'flex') : ?>
                display: flex;
                justify-content: space-between;
                align-items: center;
            <?php else : ?>
                text-align: <?php echo esc_attr($dog_pet_house_layout_option); ?>;
            <?php endif; ?>
        }
    </style>
    <?php
}
add_action('wp_head', 'dog_pet_house_page_title_customizer_css');

function dog_pet_house_pagetitle_height_css() {
    $dog_pet_house_height = get_theme_mod('dog_pet_house_pagetitle_height', 50);
    ?>
    <style type="text/css">
        header.page-header {
            padding: <?php echo esc_attr($dog_pet_house_height); ?>px 0;
        }
    </style>
    <?php
}
add_action('wp_head', 'dog_pet_house_pagetitle_height_css');

function dog_pet_house_site_logo_width() {
    $dog_pet_house_site_logo_width = get_theme_mod('dog_pet_house_site_logo_width', 200);
    ?>
    <style type="text/css">
        .site-logo img {
            max-width: <?php echo esc_attr($dog_pet_house_site_logo_width); ?>px;
        }
    </style>
    <?php
}
add_action('wp_head', 'dog_pet_house_site_logo_width');

function dog_pet_house_menu_font_size_css() {
    $dog_pet_house_menu_font_size = get_theme_mod('dog_pet_house_menu_font_size', 15);
    ?>
    <style type="text/css">
        .main-navigation a {
            font-size: <?php echo esc_attr($dog_pet_house_menu_font_size); ?>px;
        }
    </style>
    <?php
}
add_action('wp_head', 'dog_pet_house_menu_font_size_css');

function dog_pet_house_sidebar_widget_font_size_css() {
    $dog_pet_house_sidebar_widget_font_size = get_theme_mod('dog_pet_house_sidebar_widget_font_size', 21);
    ?>
    <style type="text/css">
        h2.wp-block-heading {
            font-size: <?php echo esc_attr($dog_pet_house_sidebar_widget_font_size); ?>px;
        }
    </style>
    <?php
}
add_action('wp_head', 'dog_pet_house_sidebar_widget_font_size_css');