<?php

/**
 * Pige Title Options
 *
 * @package dog_pet_house
 */

$wp_customize->add_section(
	'dog_pet_house_page_title_options',
	array(
		'panel' => 'dog_pet_house_theme_options',
		'title' => esc_html__( 'Page Title', 'dog-pet-house' ),
	)
);

$wp_customize->add_setting(
    'dog_pet_house_page_header_visibility',
    array(
        'default'           => 'all-devices',
        'sanitize_callback' => 'dog_pet_house_sanitize_select',
    )
);

$wp_customize->add_control(
    new WP_Customize_Control(
        $wp_customize,
        'dog_pet_house_page_header_visibility',
        array(
            'label'    => esc_html__( 'Page Header Visibility', 'dog-pet-house' ),
            'type'     => 'select',
            'section'  => 'dog_pet_house_page_title_options',
            'settings' => 'dog_pet_house_page_header_visibility',
            'priority' => 10,
            'choices'  => array(
                'all-devices'        => esc_html__( 'Show on all devices', 'dog-pet-house' ),
                'hide-tablet'        => esc_html__( 'Hide on Tablet', 'dog-pet-house' ),
                'hide-mobile'        => esc_html__( 'Hide on Mobile', 'dog-pet-house' ),
                'hide-tablet-mobile' => esc_html__( 'Hide on Tablet & Mobile', 'dog-pet-house' ),
                'hide-all-devices'   => esc_html__( 'Hide on all devices', 'dog-pet-house' ),
            ),
        )
    )
);


$wp_customize->add_setting( 'dog_pet_house_page_title_background_separator', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Dog_Pet_House_Separator_Custom_Control( $wp_customize, 'dog_pet_house_page_title_background_separator', array(
	'label' => __( 'Page Title BG Image & Color Setting', 'dog-pet-house' ),
	'section' => 'dog_pet_house_page_title_options',
	'settings' => 'dog_pet_house_page_title_background_separator',
)));


$wp_customize->add_setting(
	'dog_pet_house_page_header_style',
	array(
		'sanitize_callback' => 'dog_pet_house_sanitize_switch',
		'default'           => False,
	)
);

$wp_customize->add_control(
	new Dog_Pet_House_Toggle_Switch_Custom_Control(
		$wp_customize,
		'dog_pet_house_page_header_style',
		array(
			'label'   => esc_html__('Page Title Background Image', 'dog-pet-house'),
			'section' => 'dog_pet_house_page_title_options',
		)
	)
);

$wp_customize->add_setting( 'dog_pet_house_page_header_background_image', array(
    'default' => '',
    'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'dog_pet_house_page_header_background_image', array(
    'label'    => __( 'Background Image', 'dog-pet-house' ),
    'section'  => 'dog_pet_house_page_title_options',
	'description' => __('Choose either a background image or a color. If a background image is selected, the background color will not be visible.', 'dog-pet-house'),
    'settings' => 'dog_pet_house_page_header_background_image',
	'active_callback' => 'dog_pet_house_is_pagetitle_bcakground_image_enabled',
)));

$wp_customize->add_setting('dog_pet_house_page_header_image_height', array(
	'default'           => 200,
	'sanitize_callback' => 'dog_pet_house_sanitize_range_value',
));

$wp_customize->add_control(new Dog_Pet_House_Customize_Range_Control($wp_customize, 'dog_pet_house_page_header_image_height', array(
		'label'       => __('Image Height', 'dog-pet-house'),
		'section'     => 'dog_pet_house_page_title_options',
		'settings'    => 'dog_pet_house_page_header_image_height',
		'active_callback' => 'dog_pet_house_is_pagetitle_bcakground_image_enabled',
		'input_attrs' => array(
			'min'  => 0,
			'max'  => 1000,
			'step' => 5,
		),
)));


$wp_customize->add_setting('dog_pet_house_page_title_background_color_setting', array(
    'default' => '#f5f5f5',
    'sanitize_callback' => 'sanitize_hex_color',
));

$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'dog_pet_house_page_title_background_color_setting', array(
    'label' => __('Page Title Background Color', 'dog-pet-house'),
    'section' => 'dog_pet_house_page_title_options',
)));

$wp_customize->add_setting('dog_pet_house_pagetitle_height', array(
    'default'           => 50,
    'sanitize_callback' => 'dog_pet_house_sanitize_range_value',
));

$wp_customize->add_control(new Dog_Pet_House_Customize_Range_Control($wp_customize, 'dog_pet_house_pagetitle_height', array(
    'label'       => __('Set Height', 'dog-pet-house'),
    'description' => __('This setting controls the page title height when no background image is set. If a background image is set, this setting will not apply.', 'dog-pet-house'),
    'section'     => 'dog_pet_house_page_title_options',
    'settings'    => 'dog_pet_house_pagetitle_height',
    'input_attrs' => array(
        'min'  => 0,
        'max'  => 300,
        'step' => 5,
    ),
)));

$wp_customize->add_setting( 'dog_pet_house_page_title_style_separator', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Dog_Pet_House_Separator_Custom_Control( $wp_customize, 'dog_pet_house_page_title_style_separator', array(
	'label' => __( 'Page Title Styling Setting', 'dog-pet-house' ),
	'section' => 'dog_pet_house_page_title_options',
	'settings' => 'dog_pet_house_page_title_style_separator',
)));


$wp_customize->add_setting( 'dog_pet_house_page_header_heading_tag', array(
	'default'   => 'h1',
	'sanitize_callback' => 'dog_pet_house_sanitize_select',
) );

$wp_customize->add_control( 'dog_pet_house_page_header_heading_tag', array(
	'label'   => __( 'Page Title Heading Tag', 'dog-pet-house' ),
	'section' => 'dog_pet_house_page_title_options',
	'type'    => 'select',
	'choices' => array(
		'h1' => __( 'H1', 'dog-pet-house' ),
		'h2' => __( 'H2', 'dog-pet-house' ),
		'h3' => __( 'H3', 'dog-pet-house' ),
		'h4' => __( 'H4', 'dog-pet-house' ),
		'h5' => __( 'H5', 'dog-pet-house' ),
		'h6' => __( 'H6', 'dog-pet-house' ),
		'p' => __( 'p', 'dog-pet-house' ),
		'a' => __( 'a', 'dog-pet-house' ),
		'div' => __( 'div', 'dog-pet-house' ),
		'span' => __( 'span', 'dog-pet-house' ),
	),
) );



$wp_customize->add_setting('dog_pet_house_page_header_layout', array(
	'default' => 'left',
	'sanitize_callback' => 'sanitize_text_field',
));

$wp_customize->add_control('dog_pet_house_page_header_layout', array(
	'label' => __('Style', 'dog-pet-house'),
	'section' => 'dog_pet_house_page_title_options',
	'description' => __('"Flex Layout Style" wont work below 600px (mobile media)', 'dog-pet-house'),
	'settings' => 'dog_pet_house_page_header_layout',
	'type' => 'radio',
	'choices' => array(
		'left' => __('Classic', 'dog-pet-house'),
		'right' => __('Aligned Right', 'dog-pet-house'),
		'center' => __('Centered Focus', 'dog-pet-house'),
		'flex' => __('Flex Layout', 'dog-pet-house'),
	),
));