<?php

/**
 * Single Post Options
 *
 * @package dog_pet_house
 */

$wp_customize->add_section(
	'dog_pet_house_single_post_options',
	array(
		'title' => esc_html__( 'Single Post Options', 'dog-pet-house' ),
		'panel' => 'dog_pet_house_theme_options',
	)
);


// Post Options - Show / Hide Date.
$wp_customize->add_setting(
	'dog_pet_house_single_post_hide_date',
	array(
		'default'           => false,
		'sanitize_callback' => 'dog_pet_house_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Dog_Pet_House_Toggle_Switch_Custom_Control(
		$wp_customize,
		'dog_pet_house_single_post_hide_date',
		array(
			'label'   => esc_html__( 'Show / Hide Date', 'dog-pet-house' ),
			'section' => 'dog_pet_house_single_post_options',
		)
	)
);

// Post Options - Show / Hide Author.
$wp_customize->add_setting(
	'dog_pet_house_single_post_hide_author',
	array(
		'default'           => false,
		'sanitize_callback' => 'dog_pet_house_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Dog_Pet_House_Toggle_Switch_Custom_Control(
		$wp_customize,
		'dog_pet_house_single_post_hide_author',
		array(
			'label'   => esc_html__( 'Show / Hide Author', 'dog-pet-house' ),
			'section' => 'dog_pet_house_single_post_options',
		)
	)
);

// Post Options - Show / Hide Category.
$wp_customize->add_setting(
	'dog_pet_house_single_post_hide_category',
	array(
		'default'           => false,
		'sanitize_callback' => 'dog_pet_house_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Dog_Pet_House_Toggle_Switch_Custom_Control(
		$wp_customize,
		'dog_pet_house_single_post_hide_category',
		array(
			'label'   => esc_html__( 'Show / Hide Category', 'dog-pet-house' ),
			'section' => 'dog_pet_house_single_post_options',
		)
	)
);

// Post Options - Show / Hide Tag.
$wp_customize->add_setting(
	'dog_pet_house_post_hide_tags',
	array(
		'default'           => false,
		'sanitize_callback' => 'dog_pet_house_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Dog_Pet_House_Toggle_Switch_Custom_Control(
		$wp_customize,
		'dog_pet_house_post_hide_tags',
		array(
			'label'   => esc_html__( 'Show / Hide Tag', 'dog-pet-house' ),
			'section' => 'dog_pet_house_single_post_options',
		)
	)
);



// Add Separator Custom Control
$wp_customize->add_setting( 'dog_pet_house_related_post_separator', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Dog_Pet_House_Separator_Custom_Control( $wp_customize, 'dog_pet_house_related_post_separator', array(
	'label' => __( 'Enable / Disable Related Post Section', 'dog-pet-house' ),
	'section' => 'dog_pet_house_single_post_options',
	'settings' => 'dog_pet_house_related_post_separator',
) ) );

// Post Options - Show / Hide Related Posts.
$wp_customize->add_setting(
	'dog_pet_house_post_hide_related_posts',
	array(
		'default'           => false,
		'sanitize_callback' => 'dog_pet_house_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Dog_Pet_House_Toggle_Switch_Custom_Control(
		$wp_customize,
		'dog_pet_house_post_hide_related_posts',
		array(
			'label'   => esc_html__( 'Show / Hide Related Posts', 'dog-pet-house' ),
			'section' => 'dog_pet_house_single_post_options',
		)
	)
);

// Register setting for number of related posts
$wp_customize->add_setting(
	'dog_pet_house_related_posts_count',
	array(
		'default'           => '',
		'sanitize_callback' => 'absint', // Ensure it's an integer
	)
);

// Add control for number of related posts
$wp_customize->add_control(
	'dog_pet_house_related_posts_count',
	array(
		'type'        => 'number',
		'label'       => esc_html__( 'Number of Related Posts to Display', 'dog-pet-house' ),
		'section'     => 'dog_pet_house_single_post_options',
		'input_attrs' => array(
			'min'  => 1,
			'max'  => 5, // Adjust maximum based on your preference
			'step' => 1,
		),
	)
);


// Post Options - Related Post Label.
$wp_customize->add_setting(
	'dog_pet_house_post_related_post_label',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'dog_pet_house_post_related_post_label',
	array(
		'label'    => esc_html__( 'Related Posts Label', 'dog-pet-house' ),
		'section'  => 'dog_pet_house_single_post_options',
		'settings' => 'dog_pet_house_post_related_post_label',
		'type'     => 'text',
	)
);